==> mail-1.0.tar.gz: mail-1.0/source/javax/mail/BodyPart.java <==
/*
 * BodyPart.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail;

/**
 * This class models a Part that is contained within a Multipart.
 * This is an abstract class. Subclasses provide actual implementations.
 * <p>
 * BodyPart implements the Part interface.
 * Thus, it contains a set of attributes and a "content".
 * 
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public abstract class BodyPart
  implements Part
{


  /**
   * The Multipart object containing this BodyPart, if known.
   */
  protected Multipart parent = null;

  /**
   * Return the containing Multipart object, or null if not known.
   */
  public Multipart getParent()
  {
    return parent;
  }

  void setParent(Multipart multipart)
  {
    parent = multipart;
  }

}

==> mail-1.1.1.tar.gz: mail-1.1.1/source/javax/mail/BodyPart.java <==
/*
 * BodyPart.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail;

/**
 * A MIME body part. This is a MIME part occurring inside a multipart in the
 * message content.
 * 
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public abstract class BodyPart
  implements Part
{

  /**
   * The Multipart object containing this BodyPart.
   */
  protected Multipart parent = null;

  /**
   * Returns the containing Multipart object, or <code>null</code> if not
   * known.
   */
  public Multipart getParent()
  {
    return parent;
  }

  void setParent(Multipart multipart)
  {
    parent = multipart;
  }

}
